@@ -1,15 +1,19 @@
 from django.contrib import admin
 
-from httpproxy.models import Request, Response
+from httpproxy.models import Request, RequestParameter, Response
 
 
 class ResponseInline(admin.StackedInline):
     model = Response
 
+class RequestParameterInline(admin.TabularInline):
+    model = RequestParameter
+    extra = 1
+
 class RequestAdmin(admin.ModelAdmin):
     list_display = ('domain', 'port', 'path', 'querystring', 'date')
     list_filter = ('domain', 'port')
-    inlines = [ResponseInline,]
+    inlines = [RequestParameterInline, ResponseInline]
 
 class ResponseAdmin(admin.ModelAdmin):
     list_display = ('request_domain', 'request_path', 'request_querystring', 'status', 'content_type')
